# country_flags.py

country_flags = {
    'AF': '🇦🇫',  # Afghanistan
    'AL': '🇦🇱',  # Albania
    'DZ': '🇩🇿',  # Algeria
    'AS': '🇦🇸',  # American Samoa
    'AD': '🇦🇩',  # Andorra
    'AO': '🇦🇴',  # Angola
    'AI': '🇦🇮',  # Anguilla
    'AQ': '🇦🇶',  # Antarctica
    'AG': '🇦🇬',  # Antigua and Barbuda
    'AR': '🇦🇷',  # Argentina
    'AM': '🇦🇲',  # Armenia
    'AW': '🇦🇼',  # Aruba
    'AU': '🇦🇺',  # Australia
    'AT': '🇦🇹',  # Austria
    'AZ': '🇦🇿',  # Azerbaijan
    'BS': '🇧🇸',  # Bahamas
    'BH': '🇧🇭',  # Bahrain
    'BD': '🇧🇩',  # Bangladesh
    'BB': '🇧🇧',  # Barbados
    'BY': '🇧🇾',  # Belarus
    'BE': '🇧🇪',  # Belgium
    'BZ': '🇧🇿',  # Belize
    'BJ': '🇧🇯',  # Benin
    'BM': '🇧🇲',  # Bermuda
    'BT': '🇧🇹',  # Bhutan
    'BO': '🇧🇴',  # Bolivia
    'BQ': '🇧🇶',  # Bonaire, Sint Eustatius and Saba
    'BA': '🇧🇦',  # Bosnia and Herzegovina
    'BW': '🇧🇼',  # Botswana
    'BV': '🇧🇻',  # Bouvet Island
    'BR': '🇧🇷',  # Brazil
    'IO': '🇮🇴',  # British Indian Ocean Territory
    'BN': '🇧🇳',  # Brunei Darussalam
    'BG': '🇧🇬',  # Bulgaria
    'BF': '🇧🇫',  # Burkina Faso
    'BI': '🇧🇮',  # Burundi
    'CV': '🇨🇻',  # Cabo Verde
    'KH': '🇰🇭',  # Cambodia
    'CM': '🇨🇲',  # Cameroon
    'CA': '🇨🇦',  # Canada
    'KY': '🇰🇾',  # Cayman Islands
    'CF': '🇨🇫',  # Central African Republic
    'TD': '🇹🇩',  # Chad
    'CL': '🇨🇱',  # Chile
    'CN': '🇨🇳',  # China
    'CX': '🇨🇽',  # Christmas Island
    'CC': '🇨🇨',  # Cocos (Keeling) Islands
    'CO': '🇨🇴',  # Colombia
    'KM': '🇰🇲',  # Comoros
    'CD': '🇨🇩',  # Congo, Democratic Republic of the
    'CG': '🇨🇬',  # Congo, Republic of the
    'CK': '🇨🇰',  # Cook Islands
    'CR': '🇨🇷',  # Costa Rica
    'HR': '🇭🇷',  # Croatia
    'CU': '🇨🇺',  # Cuba
    'CW': '🇨🇼',  # Curaçao
    'CY': '🇨🇾',  # Cyprus
    'CZ': '🇨🇿',  # Czech Republic
    'DK': '🇩🇰',  # Denmark
    'DJ': '🇩🇯',  # Djibouti
    'DM': '🇩🇲',  # Dominica
    'DO': '🇩🇴',  # Dominican Republic
    'EC': '🇪🇨',  # Ecuador
    'EG': '🇪🇬',  # Egypt
    'SV': '🇸🇻',  # El Salvador
    'GQ': '🇬🇶',  # Equatorial Guinea
    'ER': '🇪🇷',  # Eritrea
    'EE': '🇪🇪',  # Estonia
    'SZ': '🇸🇿',  # Eswatini
    'ET': '🇪🇹',  # Ethiopia
    'FK': '🇫🇰',  # Falkland Islands
    'FO': '🇫🇴',  # Faroe Islands
    'FJ': '🇫🇯',  # Fiji
    'FI': '🇫🇮',  # Finland
    'FR': '🇫🇷',  # France
    'GF': '🇬🇫',  # French Guiana
    'PF': '🇵🇫',  # French Polynesia
    'TF': '🇹🇫',  # French Southern Territories
    'GA': '🇬🇦',  # Gabon
    'GM': '🇬🇲',  # Gambia
    'GE': '🇬🇪',  # Georgia
    'DE': '🇩🇪',  # Germany
    'GH': '🇬🇭',  # Ghana
    'GI': '🇬🇮',  # Gibraltar
    'GR': '🇬🇷',  # Greece
    'GL': '🇬🇱',  # Greenland
    'GD': '🇬🇩',  # Grenada
    'GP': '🇬🇵',  # Guadeloupe
    'GU': '🇬🇺',  # Guam
    'GT': '🇬🇹',  # Guatemala
    'GG': '🇬🇬',  # Guernsey
    'GN': '🇬🇳',  # Guinea
    'GW': '🇬🇼',  # Guinea-Bissau
    'GY': '🇬🇾',  # Guyana
    'HT': '🇭🇹',  # Haiti
    'HM': '🇭🇲',  # Heard Island and McDonald Islands
    'VA': '🇻🇦',  # Holy See
    'HN': '🇭🇳',  # Honduras
    'HK': '🇭🇰',  # Hong Kong
    'HU': '🇭🇺',  # Hungary
    'IS': '🇮🇸',  # Iceland
    'IN': '🇮🇳',  # India
    'ID': '🇮🇩',  # Indonesia
    'IR': '🇮🇷',  # Iran
    'IQ': '🇮🇶',  # Iraq
    'IE': '🇮🇪',  # Ireland
    'IM': '🇮🇲',  # Isle of Man
    'IL': '🇮🇱',  # Israel
    'IT': '🇮🇹',  # Italy
    'JM': '🇯🇲',  # Jamaica
    'JP': '🇯🇵',  # Japan
    'JE': '🇯🇪',  # Jersey
    'JO': '🇯🇴',  # Jordan
    'KZ': '🇰🇿',  # Kazakhstan
    'KE': '🇰🇪',  # Kenya
    'KI': '🇰🇮',  # Kiribati
    'KP': '🇰🇵',  # Korea, North
    'KR': '🇰🇷',  # Korea, South
    'KW': '🇰🇼',  # Kuwait
    'KG': '🇰🇬',  # Kyrgyzstan
    'LA': '🇱🇦',  # Laos
    'LV': '🇱🇻',  # Latvia
    'LB': '🇱🇧',  # Lebanon
    'LS': '🇱🇸',  # Lesotho
    'LR': '🇱🇷',  # Liberia
    'LY': '🇱🇾',  # Libya
    'LI': '🇱🇮',  # Liechtenstein
    'LT': '🇱🇹',  # Lithuania
    'LU': '🇱🇺',  # Luxembourg
    'MO': '🇲🇴',  # Macau
    'MG': '🇲🇬',  # Madagascar
    'MW': '🇲🇼',  # Malawi
    'MY': '🇲🇾',  # Malaysia
    'MV': '🇲🇻',  # Maldives
    'ML': '🇲🇱',  # Mali
    'MT': '🇲🇹',  # Malta
    'MH': '🇲🇭',  # Marshall Islands
    'MQ': '🇲🇶',  # Martinique
    'MR': '🇲🇷',  # Mauritania
    'MU': '🇲🇺',  # Mauritius
    'YT': '🇾🇹',  # Mayotte
    'MX': '🇲🇽',  # Mexico
    'FM': '🇫🇲',  # Micronesia
    'MD': '🇲🇩',  # Moldova
    'MC': '🇲🇨',  # Monaco
    'MN': '🇲🇳',  # Mongolia
    'ME': '🇲🇪',  # Montenegro
    'MS': '🇲🇸',  # Montserrat
    'MA': '🇲🇦',  # Morocco
    'MZ': '🇲🇿',  # Mozambique
    'MM': '🇲🇲',  # Myanmar
    'NA': '🇳🇦',  # Namibia
    'NR': '🇳🇷',  # Nauru
    'NP': '🇳🇵',  # Nepal
    'NL': '🇳🇱',  # Netherlands
    'NC': '🇳🇨',  # New Caledonia
    'NZ': '🇳🇿',  # New Zealand
    'NI': '🇳🇮',  # Nicaragua
    'NE': '🇳🇪',  # Niger
    'NG': '🇳🇬',  # Nigeria
    'NU': '🇳🇺',  # Niue
    'NF': '🇳🇫',  # Norfolk Island
    'MP': '🇲🇵',  # Northern Mariana Islands
    'NO': '🇳🇴',  # Norway
    'OM': '🇴🇲',  # Oman
    'PK': '🇵🇰',  # Pakistan
    'PW': '🇵🇼',  # Palau
    'PS': '🇵🇸',  # Palestine
    'PA': '🇵🇦',  # Panama
    'PG': '🇵🇬',  # Papua New Guinea
    'PY': '🇵🇾',  # Paraguay
    'PE': '🇵🇪',  # Peru
    'PH': '🇵🇭',  # Philippines
    'PN': '🇵🇳',  # Pitcairn
    'PL': '🇵🇱',  # Poland
    'PT': '🇵🇹',  # Portugal
    'PR': '🇵🇷',  # Puerto Rico
    'QA': '🇶🇦',  # Qatar
    'RE': '🇷🇪',  # Réunion
    'RO': '🇷🇴',  # Romania
    'RU': '🇷🇺',  # Russia
    'RW': '🇷🇼',  # Rwanda
    'BL': '🇧🇱',  # Saint Barthélemy
    'SH': '🇸🇭',  # Saint Helena
    'KN': '🇰🇳',  # Saint Kitts and Nevis
    'LC': '🇱🇨',  # Saint Lucia
    'MF': '🇲🇫',  # Saint Martin
    'SX': '🇸🇽',  # Sint Maarten
    'SB': '🇸🇧',  # Solomon Islands
    'SC': '🇸🇨',  # Seychelles
    'SD': '🇸🇩',  # Sudan
    'SE': '🇸🇪',  # Sweden
    'SG': '🇸🇬',  # Singapore
    'SX': '🇸🇽',  # Sint Maarten
    'SI': '🇸🇮',  # Slovenia
    'SJ': '🇸🇯',  # Svalbard and Jan Mayen
    'SK': '🇸🇰',  # Slovakia
    'SI': '🇸🇮',  # Slovenia
    'SO': '🇸🇴',  # Somalia
    'ZA': '🇿🇦',  # South Africa
    'GS': '🇬🇸',  # South Georgia and the South Sandwich Islands
    'SS': '🇸🇸',  # South Sudan
    'ES': '🇪🇸',  # Spain
    'LK': '🇱🇰',  # Sri Lanka
    'SD': '🇸🇩',  # Sudan
    'SR': '🇸🇷',  # Suriname
    'SJ': '🇸🇯',  # Svalbard and Jan Mayen
    'SZ': '🇸🇿',  # Eswatini
    'SE': '🇸🇪',  # Sweden
    'CH': '🇨🇭',  # Switzerland
    'SY': '🇸🇾',  # Syria
    'TW': '🇹🇼',  # Taiwan
    'TJ': '🇹🇯',  # Tajikistan
    'TZ': '🇹🇿',  # Tanzania
    'TH': '🇹🇭',  # Thailand
    'TL': '🇹🇱',  # Timor-Leste
    'TG': '🇹🇬',  # Togo
    'TK': '🇹🇰',  # Tokelau
    'TO': '🇹🇴',  # Tonga
    'TT': '🇹🇹',  # Trinidad and Tobago
    'TN': '🇹🇳',  # Tunisia
    'TR': '🇹🇷',  # Turkey
    'TM': '🇹🇲',  # Turkmenistan
    'TC': '🇹🇨',  # Turks and Caicos Islands
    'TV': '🇹🇻',  # Tuvalu
    'UG': '🇺🇬',  # Uganda
    'UA': '🇺🇦',  # Ukraine
    'AE': '🇦🇪',  # United Arab Emirates
    'GB': '🇬🇧',  # United Kingdom
    'US': '🇺🇸',  # United States
    'UY': '🇺🇾',  # Uruguay
    'UZ': '🇺🇿',  # Uzbekistan
    'VU': '🇻🇺',  # Vanuatu
    'VE': '🇻🇪',  # Venezuela
    'VN': '🇻🇳',  # Vietnam
    'WF': '🇼🇫',  # Wallis and Futuna
    'EH': '🇪🇭',  # Western Sahara
    'YE': '🇾🇪',  # Yemen
    'ZM': '🇿🇲',  # Zambia
    'ZW': '🇿🇼',  # Zimbabwe
}
